#include "touchpadsettingsui.h"
#include <QDBusInterface>

#include <unistd.h>

const quint32 maxCycleNum = 3;
const QByteArray themeSchemas = "org.ukui.style";
const QString iconThemeName = "icon-theme-name";

#define KYLIN_USER_GUIDE_PATH              "/"
#define KYLIN_USER_GUIDE_SERVICE           "com.kylinUserGuide.hotel"
#define KYLIN_USER_GUIDE_INTERFACE         "com.guide.hotel"

TouchpadUI::TouchpadUI(QWidget *parent)
    : QWidget(parent)
    , m_cycleNum(0)
    , m_iconThemeGSettings(nullptr)
{
    mVlayout = new QVBoxLayout(this);
    mVlayout->setContentsMargins(40, 16, 40, 0);
    initUI();
    initConnection();
    monitorIconThemeChange();
}

TouchpadUI::~TouchpadUI()
{
    if(m_iconThemeGSettings) {
        m_iconThemeGSettings->deleteLater();
        m_iconThemeGSettings = nullptr;
    }
}

QFrame* TouchpadUI::myLine()
{
    QFrame *line = new QFrame(this);
    line->setMinimumSize(QSize(0, 1));
    line->setMaximumSize(QSize(16777215, 1));
    line->setLineWidth(0);
    line->setFrameShape(QFrame::HLine);
    line->setFrameShadow(QFrame::Sunken);

    return line;
}

void TouchpadUI::initUI()
{
    QFrame *touchpadFrame = new QFrame(this);
    touchpadFrame->setMinimumSize(550, 0);
    touchpadFrame->setMaximumSize(16777215, 16777215);
    touchpadFrame->setFrameShape(QFrame::Box);

    QVBoxLayout *touchpadLyt = new QVBoxLayout(touchpadFrame);
    touchpadLyt->setContentsMargins(0, 0, 0, 0);

    mTouchpadSetTitleLabel = new QLabel(this);
    mTouchpadSetTitleLabel->setText(tr("Touchpad"));
    QHBoxLayout *h_touchpad_layout = new QHBoxLayout(this);
    h_touchpad_layout->setContentsMargins(16, 0, 0, 0);
    h_touchpad_layout->addWidget(mTouchpadSetTitleLabel);
    h_touchpad_layout->addStretch();

    /* MouseDisable */
    mMouseDisableFrame = new QFrame(this);
    mMouseDisableFrame->setFrameShape(QFrame::Shape::Box);
    mMouseDisableFrame->setMinimumSize(550, 60);
    mMouseDisableFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *MouseDisableHLayout = new QHBoxLayout();

    mMouseDisableBtn = new TouchPadSetting::SwitchButton(this);
    //~ contents_path /Touchpad/Disable touchpad when using the mouse
    mMouseDisableLabel = new QLabel(tr("Disable touchpad when using the mouse"), this);
    MouseDisableHLayout->addSpacing(16);
    MouseDisableHLayout->addWidget(mMouseDisableLabel);
    MouseDisableHLayout->addStretch();
    MouseDisableHLayout->addWidget(mMouseDisableBtn);
    MouseDisableHLayout->addSpacing(16);

    mMouseDisableFrame->setLayout(MouseDisableHLayout);

    /* CursorSpeed */
    mPointerSpeedFrame = new QFrame(this);
    mPointerSpeedFrame->setFrameShape(QFrame::Shape::Box);
    mPointerSpeedFrame->setMinimumSize(550, 60);
    mPointerSpeedFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *pointerSpeedHLayout = new QHBoxLayout();

     //~ contents_path /Touchpad/Pointer Speed
    mPointerSpeedLabel = new QLabel(tr("Pointer Speed"), this);
    mPointerSpeedLabel->setMinimumWidth(200);
    mPointerSpeedSlowLabel = new QLabel(tr("Slow"), this);
    mPointerSpeedFastLabel = new QLabel(tr("Fast"), this);
    mPointerSpeedSlider = new QSlider(Qt::Horizontal);
    mPointerSpeedSlider->setMinimum(10);
    mPointerSpeedSlider->setMaximum(1000);
    mPointerSpeedSlider->setSingleStep(50);
    mPointerSpeedSlider->setPageStep(50);
    pointerSpeedHLayout->addSpacing(16);
    pointerSpeedHLayout->addWidget(mPointerSpeedLabel);
    pointerSpeedHLayout->addWidget(mPointerSpeedSlowLabel);
    pointerSpeedHLayout->addWidget(mPointerSpeedSlider);
    pointerSpeedHLayout->addWidget(mPointerSpeedFastLabel);
    pointerSpeedHLayout->addSpacing(16);

    mPointerSpeedFrame->setLayout(pointerSpeedHLayout);

    /* TypingDisableFrame */
    mTypingDisableFrame = new QFrame(this);
    mTypingDisableFrame->setFrameShape(QFrame::Shape::Box);
    mTypingDisableFrame->setMinimumSize(550, 60);
    mTypingDisableFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *TypingDisableHLayout = new QHBoxLayout();

    mTypingDisableBtn = new TouchPadSetting::SwitchButton(this);
     //~ contents_path /Touchpad/Disable touchpad when typing
    mTypingDisableLabel = new QLabel(tr("Disable touchpad when typing"), this);
    TypingDisableHLayout->addSpacing(16);
    TypingDisableHLayout->addWidget(mTypingDisableLabel);
    TypingDisableHLayout->addStretch();
    TypingDisableHLayout->addWidget(mTypingDisableBtn);
    TypingDisableHLayout->addSpacing(16);

    mTypingDisableFrame->setLayout(TypingDisableHLayout);

    /* click */
    mClickFrame = new QFrame(this);
    mClickFrame->setFrameShape(QFrame::Shape::Box);
    mClickFrame->setMinimumSize(550, 60);
    mClickFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *ClickHLayout = new QHBoxLayout();

    mClickBtn = new TouchPadSetting::SwitchButton(this);
    //~ contents_path /Touchpad/Touch and click on the touchpad
    mClickLabel = new QLabel(tr("Touch and click on the touchpad"), this);
    ClickHLayout->addSpacing(16);
    ClickHLayout->addWidget(mClickLabel);
    ClickHLayout->addStretch();
    ClickHLayout->addWidget(mClickBtn);
    ClickHLayout->addSpacing(16);

    mClickFrame->setLayout(ClickHLayout);

    /* ScrollSlideFrame */
    mScrollSlideFrame = new QFrame(this);
    mScrollSlideFrame->setFrameShape(QFrame::Shape::Box);
    mScrollSlideFrame->setMinimumSize(550, 60);
    mScrollSlideFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *ScrollSlideHLayout = new QHBoxLayout();

    mScrollSlideBtn = new TouchPadSetting::SwitchButton(this);
     //~ contents_path /Touchpad/Scroll bar slides with finger
    mScrollSlideLabel = new QLabel(tr("Scroll bar slides with finger"), this);
    ScrollSlideHLayout->addSpacing(16);
    ScrollSlideHLayout->addWidget(mScrollSlideLabel);
    ScrollSlideHLayout->addStretch();
    ScrollSlideHLayout->addWidget(mScrollSlideBtn);
    ScrollSlideHLayout->addSpacing(16);

    mScrollSlideFrame->setLayout(ScrollSlideHLayout);

    /* ScrollAreaFrame */
    mScrollAreaFrame = new QFrame(this);
    mScrollAreaFrame->setFrameShape(QFrame::Shape::Box);
    mScrollAreaFrame->setMinimumSize(550, 60);
    mScrollAreaFrame->setMaximumSize(16777215, 60);

    QHBoxLayout *ScrollAreaHLayout = new QHBoxLayout();

     //~ contents_path /Touchpad/Scrolling area
    mScrollAreaLabel = new QLabel(tr("Scrolling area"), this);
    mScrollTypeComBox = new QComboBox;
    mScrollTypeComBox->addItem(tr("Two-finger scrolling in the middle area"), V_FINGER_KEY);
    mScrollTypeComBox->addItem(tr("Edge scrolling"), V_EDGE_KEY);
    mScrollTypeComBox->addItem(tr("Disable scrolling"), N_SCROLLING);
    ScrollAreaHLayout->addSpacing(16);
    ScrollAreaHLayout->addWidget(mScrollAreaLabel);
    ScrollAreaHLayout->addWidget(mScrollTypeComBox);
    ScrollAreaHLayout->addSpacing(16);

    mScrollAreaFrame->setLayout(ScrollAreaHLayout);
#if 0
    /* TouchpadGestureFrame */
    QWidget *padGestureWidget = new QWidget(this);
//    padGestureWidget->setMinimumSize(550, 504);
//    padGestureWidget->setMaximumSize(16777215, 16777215);
    QVBoxLayout *vPadLayout = new QVBoxLayout(padGestureWidget);
    vPadLayout->setContentsMargins(0, 40, 0, 0);
    vPadLayout->setSpacing(16);
    // "手势" Label
    QLabel *gestureLabel = new QLabel(tr("gesture"), padGestureWidget);
    QHBoxLayout *hLabelLayout = new QHBoxLayout;
    hLabelLayout->setContentsMargins(16, 0, 0, 0);
    hLabelLayout->addWidget(gestureLabel);
    hLabelLayout->addStretch();
    // "更多手势" Button
    QPushButton *moreGestureLabel = new QPushButton(tr("more gesture"), padGestureWidget);
    QHBoxLayout *hLabelLayout_1 = new QHBoxLayout;
    hLabelLayout_1->setContentsMargins(0, 0, 0, 0);
    hLabelLayout_1->addWidget(moreGestureLabel);
    hLabelLayout_1->addStretch();
//    moreGestureLabel->hide();
    // "手势显示" Frame
    QFrame *gestureFrame = new QFrame(padGestureWidget);
    gestureFrame->setMinimumSize(550, 436);
    gestureFrame->setMaximumSize(16777215, 16777215);
    gestureFrame->setFrameShadow(QFrame::Plain);
    gestureFrame->setFrameShape(QFrame::Box);
    QHBoxLayout *gestureLayout = new QHBoxLayout(gestureFrame);
    gestureLayout->setContentsMargins(0, 0, 0, 0);
    gestureLayout->setSpacing(16);
    // Item 选择部分
    QWidget *gestureItem = new QWidget(gestureFrame);
    QVBoxLayout *vLayout_1 = new QVBoxLayout(gestureItem);
    vLayout_1->setContentsMargins(16, 16, 8, 16);
    vLayout_1->setSpacing(4);
    gestureWidget *threeFingerClick = new gestureWidget(gestureItem);
    threeFingerClick->setActionText(tr("three fingers click"));
    threeFingerClick->setFunctionText(tr("show global search"));
    gestureWidget *fourSwipeDown = new gestureWidget(gestureItem);
    fourSwipeDown->setActionText(tr("swipe three fingers down"));
    fourSwipeDown->setFunctionText(tr("show desktop"));
    gestureWidget *fourSwipeUp = new gestureWidget(gestureItem);
    fourSwipeUp->setActionText(tr("swipe three fingers up"));
    fourSwipeUp->setFunctionText(tr("open the multitasking view"));
    gestureWidget *horizenThreeSwipe = new gestureWidget(gestureItem);
    horizenThreeSwipe->setActionText(tr("swipe three fingers horizontally"));
    horizenThreeSwipe->setFunctionText(tr("switch windows"));
    gestureWidget *fourFingerClick = new gestureWidget(gestureItem);
    fourFingerClick->setActionText(tr("four fingers click"));
    fourFingerClick->setFunctionText(tr("show sidebar"));
    gestureWidget *horizenFourSwipe = new gestureWidget(gestureItem);
    horizenFourSwipe->setActionText(tr("swipe four fingers horizontally"));
    horizenFourSwipe->setFunctionText(tr("switch desktop"));
    m_gestureArray.append(threeFingerClick);
    m_gestureArray.append(fourSwipeDown);
    m_gestureArray.append(fourSwipeUp);
    m_gestureArray.append(horizenThreeSwipe);
    m_gestureArray.append(fourFingerClick);
    m_gestureArray.append(horizenFourSwipe);
    vLayout_1->addWidget(threeFingerClick);
    vLayout_1->addWidget(fourSwipeDown);
    vLayout_1->addWidget(fourSwipeUp);
    vLayout_1->addWidget(horizenThreeSwipe);
    vLayout_1->addWidget(fourFingerClick);
    vLayout_1->addWidget(horizenFourSwipe);
    connect(threeFingerClick, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::threeFingerClick);
    });
    connect(fourSwipeDown, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::threeFingerSwipeDown);
    });
    connect(fourSwipeUp, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::threeFingerSwipeUp);
    });
    connect(horizenThreeSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::threeFingersHorizontalSwipe);
    });
    connect(fourFingerClick, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::fourFingerClick);
    });
    connect(horizenFourSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::fourFingersHorizontalSwipe);
    });
    connect(moreGestureLabel, &QPushButton::clicked, this, [=]() {
        QString pluName = "ukui-control-center/Touchpad";
        qDebug() << pluName;
        QString service_name = "com.kylinUserGuide.hotel_" + QString::number(getuid());
        QDBusInterface interface(service_name,
                                 KYLIN_USER_GUIDE_PATH,
                                 KYLIN_USER_GUIDE_INTERFACE,
                                 QDBusConnection::sessionBus(),
                                 this);
        QDBusMessage msg = interface.call("showGuide", pluName);
    });

    foreach (auto gesture, m_gestureArray) {
        connect(gesture, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
        connect(this, &TouchpadUI::iconThemeChangedSignal, gesture, &gestureWidget::themeChanged);
    }
    connect(threeFingerClick, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    connect(fourSwipeDown, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    connect(fourSwipeUp, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    connect(horizenThreeSwipe, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    connect(fourFingerClick, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    connect(horizenFourSwipe, &gestureWidget::loseFocus, this, &TouchpadUI::stopGif);
    // Gif 播放部分
    QWidget *videoWidget = new QWidget(gestureFrame);
    QLabel *video_label = new QLabel(videoWidget);
    video_label->setFixedSize(400, 400);
    QVBoxLayout *videoLayout = new QVBoxLayout(videoWidget);
    videoLayout->setContentsMargins(0, 0, 0, 0);
    videoLayout->addWidget(video_label);
    m_movie = new QMovie;
    m_movie->setFileName(":/gif/resources/三指轻点.gif");
    m_movie->setScaledSize(QSize(384, 450));
    m_movie->start();
    m_movie->stop();
    video_label->setMovie(m_movie);

    gestureLayout->addWidget(gestureItem);
    gestureLayout->addWidget(videoWidget);
    vPadLayout->addLayout(hLabelLayout);
    vPadLayout->addWidget(gestureFrame);
    vPadLayout->addLayout(hLabelLayout_1);
    touchpadFrame->adjustSize();
#endif
    /* addwidget */
    QFrame *mouseAndSpeedLine = myLine();
    QFrame *speedAndTypingLine = myLine();
    QFrame *typingAndClickLine = myLine();
    QFrame *clickAndSlideLine = myLine();
    QFrame *slideAndAreaLine = myLine();

    touchpadLyt->addWidget(mMouseDisableFrame);
    touchpadLyt->addWidget(mouseAndSpeedLine);
    touchpadLyt->addWidget(mPointerSpeedFrame);
    touchpadLyt->addWidget(speedAndTypingLine);
    touchpadLyt->addWidget(mTypingDisableFrame);
    touchpadLyt->addWidget(typingAndClickLine);
    touchpadLyt->addWidget(mClickFrame);
    touchpadLyt->addWidget(clickAndSlideLine);
    touchpadLyt->addWidget(mScrollSlideFrame);
    touchpadLyt->addWidget(slideAndAreaLine);
    touchpadLyt->addWidget(mScrollAreaFrame);
    touchpadLyt->setSpacing(0);

    mVlayout->addLayout(h_touchpad_layout);
    mVlayout->setSpacing(8);
    mVlayout->addWidget(touchpadFrame);
    mVlayout->setSpacing(16);
#if 0
    mVlayout->addWidget(padGestureWidget);
#endif

    mVlayout->addStretch();
}

void TouchpadUI::initConnection()
{
    QByteArray touchpadId(kTouchpadSchemas);

    if (QGSettings::isSchemaInstalled(touchpadId)) {
        mTouchpadGsetting = new QGSettings(kTouchpadSchemas, QByteArray(), this);

        initEnableStatus();

        connect(mMouseDisableBtn, &TouchPadSetting::SwitchButton::checkedChanged, this, &TouchpadUI::mouseDisableSlot);

        connect(mPointerSpeedSlider, &QSlider::valueChanged, this, &TouchpadUI::pointerSpeedSlot);

        connect(mTypingDisableBtn, &TouchPadSetting::SwitchButton::checkedChanged, this, &TouchpadUI::typingDisableSlot);

        connect(mClickBtn, &TouchPadSetting::SwitchButton::checkedChanged, this, &TouchpadUI::clickSlot);

        connect(mScrollSlideBtn, &TouchPadSetting::SwitchButton::checkedChanged, this, &TouchpadUI::scrollSlideSlot);

        connect(mScrollTypeComBox, QOverload<const QString &>::of(&QComboBox::currentIndexChanged),
                this, &TouchpadUI::scrolltypeSlot);

        gsettingConnectUi();
    }
}

void TouchpadUI::gsettingConnectUi()
{
    //命令行指针速度改变 key 值，界面做出相应的改变
    connect(mTouchpadGsetting, &QGSettings::changed, this, [=](const QString &key) {
       if (key == "motionAcceleration") {
           mPointerSpeedSlider->blockSignals(true);
           mPointerSpeedSlider->setValue((kPointerSpeedMin + kPointerSpeedMax - mTouchpadGsetting->get(kPointerSpeedKey).toDouble()) * 100);
           mPointerSpeedSlider->blockSignals(false);
       }
    });
}

void TouchpadUI::initEnableStatus()
{
    // 插入鼠标时候禁用触摸板
    mMouseDisableBtn->blockSignals(true);
    mMouseDisableBtn->setChecked(mTouchpadGsetting->get(kMouseDisableKey).toBool());
    mMouseDisableBtn->blockSignals(false);

    // 初始化光标速度
    mPointerSpeedSlider->blockSignals(true);
    mPointerSpeedSlider->setValue((kPointerSpeedMin + kPointerSpeedMax - mTouchpadGsetting->get(kPointerSpeedKey).toDouble()) * 100);
    mPointerSpeedSlider->blockSignals(false);

    // 初始化打字时禁用触摸板
    mTypingDisableBtn->blockSignals(true);
    mTypingDisableBtn->setChecked(mTouchpadGsetting->get(kTypingDisableKey).toBool());
    mTypingDisableBtn->blockSignals(false);

    // 初始化触摸板轻触点击
    mClickBtn->blockSignals(true);
    mClickBtn->setChecked(mTouchpadGsetting->get(kClickKey).toBool());
    mClickBtn->blockSignals(false);

    // 初始化滚动条跟随手指滑动
    mScrollSlideBtn->blockSignals(true);
    mScrollSlideBtn->setChecked(!mTouchpadGsetting->get(kScrollSlideKey).toBool());
    mScrollSlideBtn->blockSignals(false);

    //初始化滚动
    mScrollTypeComBox->blockSignals(true);
    mScrollTypeComBox->setCurrentIndex(mScrollTypeComBox->findData(_findKeyScrollingType()));
    mScrollTypeComBox->blockSignals(false);

    // 边界滚动默认水平边界有效
    if (QString::compare(V_EDGE_KEY, mScrollTypeComBox->currentData().toString()) == 0) {
        mTouchpadGsetting->set(H_EDGE_KEY, true);
        mTouchpadGsetting->set(H_FINGER_KEY, false);
    }
    if (QString::compare(V_FINGER_KEY, mScrollTypeComBox->currentData().toString()) == 0) {
        mTouchpadGsetting->set(H_EDGE_KEY, false);
        mTouchpadGsetting->set(H_FINGER_KEY, true);
    }
    if (QString::compare(N_SCROLLING, mScrollTypeComBox->currentData().toString()) == 0) {
        mTouchpadGsetting->set(H_EDGE_KEY, false);
        mTouchpadGsetting->set(H_FINGER_KEY, false);
    }
}

QString TouchpadUI::_findKeyScrollingType()
{
    if (mTouchpadGsetting->get(V_EDGE_KEY).toBool()) {
        return V_EDGE_KEY;
    }

    if (mTouchpadGsetting->get(V_FINGER_KEY).toBool()) {
        return V_FINGER_KEY;
    }

    return N_SCROLLING;
}

/* slot functions */
void TouchpadUI::mouseDisableSlot(bool status)
{
    mTouchpadGsetting->set(kMouseDisableKey, status);
}

void TouchpadUI::pointerSpeedSlot(int value)
{
    mTouchpadGsetting->set(kPointerSpeedKey, kPointerSpeedMin + kPointerSpeedMax-static_cast<double>(value) / mPointerSpeedSlider->maximum() * 10);
}

void TouchpadUI::typingDisableSlot(bool status)
{
    mTouchpadGsetting->set(kTypingDisableKey, status);
}

void TouchpadUI::clickSlot(bool status)
{
    mTouchpadGsetting->set(kClickKey, status);
}

void TouchpadUI::scrollSlideSlot(bool status)
{
    mTouchpadGsetting->set(kScrollSlideKey, !status);
}

void TouchpadUI::scrolltypeSlot()
{
    //旧滚动类型设置为false，新滚动类型设置为true
    QString data = mScrollTypeComBox->currentData().toString();
    // 禁用滚动
    if (QString::compare(data, N_SCROLLING) == 0) {
        mTouchpadGsetting->set(V_EDGE_KEY, false);
        mTouchpadGsetting->set(H_EDGE_KEY, false);
        mTouchpadGsetting->set(V_FINGER_KEY, false);
        mTouchpadGsetting->set(H_FINGER_KEY, false);
    }
    // 边界滚动:垂直边界+水平边界
    if (QString::compare(data, V_EDGE_KEY) == 0) {
        mTouchpadGsetting->set(V_EDGE_KEY, true);
        mTouchpadGsetting->set(H_EDGE_KEY, true);
        mTouchpadGsetting->set(V_FINGER_KEY, false);
        mTouchpadGsetting->set(H_FINGER_KEY, false);
    }
    // 中间双指:垂直中间+水平中间
    if (QString::compare(data, V_FINGER_KEY) == 0) {
        mTouchpadGsetting->set(V_EDGE_KEY, false);
        mTouchpadGsetting->set(H_EDGE_KEY, false);
        mTouchpadGsetting->set(V_FINGER_KEY, true);
        mTouchpadGsetting->set(H_FINGER_KEY, true);
    }
}

void TouchpadUI::playGif(screenGestureType type)
{
    switch (type) {
    case screenGestureType::threeFingerClick:
        m_movie->setFileName(":/gif/resources/三指轻点.gif");
        break;
    case screenGestureType::threeFingerSwipeDown:
        m_movie->setFileName(":/gif/resources/三指向下滑.gif");
        break;
    case screenGestureType::threeFingerSwipeUp:
        m_movie->setFileName(":/gif/resources/三指向上滑.gif");
        break;
    case screenGestureType::threeFingersHorizontalSwipe:
        m_movie->setFileName(":/gif/resources/三指左右滑动.gif");
        break;
    case screenGestureType::fourFingerClick:
        m_movie->setFileName(":/gif/resources/四指轻点.gif");
        break;
    case screenGestureType::fourFingersHorizontalSwipe:
        m_movie->setFileName(":/gif/resources/四指左右滑动.gif");
        break;
    default:
        break;
    }
    m_movie->stop();
    m_cycleNum = 0;
    m_movie->start();
}

void TouchpadUI::stopGif()
{
    m_movie->stop();
//     停止播放后，跳转到第一页
    m_movie->jumpToFrame(0);
}

void TouchpadUI::monitorIconThemeChange()
{
    QByteArray themeId(themeSchemas);
    if (QGSettings::isSchemaInstalled(themeId)) {
        m_iconThemeGSettings = new QGSettings(themeId);
        connect(m_iconThemeGSettings, &QGSettings::changed, this, [=](const QString &key) {
//            qDebug() << "get signal from theme:" << key;
            if (key == "iconThemeName") {
//                QString iconTheme = m_iconThemeGSettings->get(iconThemeName).toString();
//                qDebug() << "IconThemeName: " << iconTheme;
                emit iconThemeChangedSignal();
            }
        });
    }
}
