#include "gesturewidget.h"
#include <QLabel>
#include <QString>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QPixmap>
#include <QIcon>
#include <QResizeEvent>
#include <QByteArray>
#include <QDebug>

const QString iconName = "video-x-generic-symbolic";

gestureWidget::gestureWidget(QWidget *parent) : QPushButton(parent)
{
    setFocusPolicy(Qt::FocusPolicy::ClickFocus);
    setMinimumWidth(370);
    setFixedHeight(64);
    setProperty("useButtonPalette", true);
    setStyleSheet("QPushButton:!checked{background-color: palette(base)}");
    QVBoxLayout *vlayout = new QVBoxLayout(this);
    vlayout->setContentsMargins(16, 7, 0, 7);
    vlayout->setSpacing(0);
    m_action = new QLabel(this);
    m_action->setScaledContents(true);
//    m_action->setStyleSheet("background-color:yellow");
    m_playIcon = new QLabel(this);
    m_playIcon->setAlignment(Qt::AlignVCenter);
    // 上边距设为 1 是为了让图标居中，可能是 QT 的 bug
    m_playIcon->setContentsMargins(0, 1, 0, 0);
//    m_playIcon->setStyleSheet("border-image: none; background: yellow; border:none");

    if(QIcon::hasThemeIcon(iconName)) {
        QIcon play = QIcon::fromTheme(iconName);
        m_playIcon->setPixmap(play.pixmap(QSize(16, 16)));
    }
    else {
        qDebug() << __func__ << __LINE__ << "icon not exist !";
    }
    QHBoxLayout *hlayout = new QHBoxLayout;
    hlayout->setContentsMargins(0, 0, 0, 0);
    hlayout->setSpacing(6);
    hlayout->addWidget(m_action, 0, Qt::AlignVCenter);
    hlayout->addWidget(m_playIcon, 0, Qt::AlignVCenter);
    hlayout->addStretch();
    m_function = new QLabel(this);
    m_function->setStyleSheet("color: #818181");
    vlayout->addLayout(hlayout);
    vlayout->addWidget(m_function);
}

gestureWidget::~gestureWidget()
{

}

void gestureWidget::themeChanged()
{
    if(QIcon::hasThemeIcon(iconName)) {
        QIcon play = QIcon::fromTheme(iconName);
        m_playIcon->setPixmap(play.pixmap(QSize(16, 16)));
    }
    else {
        qDebug() << __func__ << __LINE__ << "icon not exist !";
    }
}

void gestureWidget::setActionText(const QString &actionText) const
{
    m_action->setText(actionText);
}

void gestureWidget::setFunctionText(const QString &functionText) const
{
    m_function->setText(functionText);
}

void gestureWidget::focusInEvent(QFocusEvent *e)
{
//    qDebug() << "gestureWidget::focusInEvent()" << m_action->text() << e;
    if(e->reason() == Qt::FocusReason::MouseFocusReason) {
        emit getFocus();
    }
    QPushButton::focusInEvent(e);
}

void gestureWidget::focusOutEvent(QFocusEvent *e)
{
//    qDebug() << "gestureWidget::focusOutEvent()" << m_action->text() << e;
    if(e->reason() == Qt::FocusReason::MouseFocusReason) {
        emit loseFocus();
    }
    QPushButton::focusOutEvent(e);
}
