#include "touchscreen-settings.h"
#include "touchscreen.h"
#include <QLocale>
#include <QTranslator>
#include <QApplication>
#include <QTouchDevice>

TouchscreenSettings::TouchscreenSettings() : mFirstLoad(true)
{
    QTranslator* translator = new QTranslator(this);
    translator->load("/usr/share/touchscreen-settings/translations/" + QLocale::system().name());
    QApplication::installTranslator(translator);

    pluginName = tr("TouchScreen");
    pluginType = DEVICES;
}

TouchscreenSettings::~TouchscreenSettings()
{
    //! ukui-control-center is responsible for destroying pluginWidget
}

QString TouchscreenSettings::plugini18nName()
{
    return pluginName;
}

int TouchscreenSettings::pluginTypes()
{
    return pluginType;
}

QWidget *TouchscreenSettings::pluginUi()
{
    if (mFirstLoad) {
        mFirstLoad = false;
        pluginWidget = new TouchScreen;
        pluginWidget->adjustSize();
        pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
    }
    return pluginWidget;
}

bool TouchscreenSettings::isEnable() const
{
    QList<const QTouchDevice *> devices = QTouchDevice::devices();
    for (auto device: devices) {
        if(device->type() == QTouchDevice::TouchScreen)
            return true;
    }
    return false;
}

const QString TouchscreenSettings::name() const
{
    return QStringLiteral("TouchScreen");
}

bool TouchscreenSettings::isShowOnHomePage() const
{
    return true;
}

QIcon TouchscreenSettings::icon() const
{
    return QIcon::fromTheme("ukui-gesture-symbolic");
}

QString TouchscreenSettings::translationPath() const
{
    return "/usr/share/touchscreen-settings/translations/%1.ts";
}

void TouchscreenSettings::initSearchText()
{
}
