#include "touchscreen.h"
#include "ui_touchscreen.h"
#include <QVBoxLayout>
#include <QUrl>
#include <QDebug>
#include <QResizeEvent>
#include <QPalette>
#include <QPushButton>
#include <QDBusInterface>

#include <unistd.h>

const quint32 maxCycleNum = 3;
const QByteArray themeSchemas = "org.ukui.style";
const QString iconThemeName = "icon-theme-name";

#define KYLIN_USER_GUIDE_PATH              "/"
#define KYLIN_USER_GUIDE_SERVICE           "com.kylinUserGuide.hotel"
#define KYLIN_USER_GUIDE_INTERFACE         "com.guide.hotel"

TouchScreen::TouchScreen(QWidget *parent)
    : QWidget(parent)
    , ui(new Ui::TouchScreen)
    , m_cycleNum(0)
    , m_iconThemeGSettings(nullptr)
{
    ui->setupUi(this);
    initUI();
    loadGif();
    monitorIconThemeChange();
}

TouchScreen::~TouchScreen()
{
    delete ui;
    if(m_iconThemeGSettings) {
        m_iconThemeGSettings->deleteLater();
        m_iconThemeGSettings = nullptr;
    }
}

bool TouchScreen::eventFilter(QObject *watched, QEvent *event)
{
//    if (watched == videoWidget) {
//        qDebug() << __func__ << event;
//    }
    return eventFilter(watched, event);
}

void TouchScreen::monitorIconThemeChange()
{
    QByteArray themeId(themeSchemas);
    if (QGSettings::isSchemaInstalled(themeId)) {
        m_iconThemeGSettings = new QGSettings(themeId);
        connect(m_iconThemeGSettings, &QGSettings::changed, this, [=](const QString &key) {
            if (key == "iconThemeName") {
                emit iconThemeChangedSignal();
            }
        });
    }
}

void TouchScreen::initUI()
{
    qDebug() << "test" <<  __func__;

//    QFont font;
//    font.setPointSize(14);
//    ui->touchscreen_label->setFont(font);

//    QPalette paltte = this->palette();
//    paltte.setColor(QPalette::Window, paltte.base().color());
//    setPalette(paltte);


//    setAttribute(Qt::WA_TranslucentBackground, true);
//    setStyleSheet("background:transparent");
//    ui->moreGestureButton->setProperty("useButtonPalette", true);
//    ui->moreGestureButton->setStyleSheet("QPushButton:!checked{background-color: palette(base)}");

    //~ contents_path /TouchScreen/touchscreen gesture
    ui->touchscreen_label->setText(tr("touchscreen gesture"));
    //~ contents_path /TouchScreen/more gesture
    ui->moreGestureButton->setText(tr("more gesture"));
//    ui->moreGestureButton->hide();

    QVBoxLayout *vlayout = new QVBoxLayout(ui->gesture_widget);
    vlayout->setContentsMargins(8, 0, 16, 0);
    vlayout->setSpacing(4);

    gestureWidget *buttomSwipe = new gestureWidget(ui->gesture_widget);
    buttomSwipe->setActionText(tr("swipe up from the bottom edge"));
    buttomSwipe->setFunctionText(tr("open the multitasking view"));

    gestureWidget *topSwipe = new gestureWidget(ui->gesture_widget);
    topSwipe->setActionText(tr("swipe down from the top edge"));
    topSwipe->setFunctionText(tr("show desktop"));

    gestureWidget *rightSwipe = new gestureWidget(ui->gesture_widget);
    rightSwipe->setActionText(tr("swipe left from the right edge"));
    rightSwipe->setFunctionText(tr("show sidebar"));

    gestureWidget *downSwipe = new gestureWidget(ui->gesture_widget);
    downSwipe->setActionText(tr("swipe four fingers down anywhere"));
    downSwipe->setFunctionText(tr("show global search"));

    gestureWidget *horizenSwipe = new gestureWidget(ui->gesture_widget);
    horizenSwipe->setActionText(tr("swipe four fingers horizontally"));
    horizenSwipe->setFunctionText(tr("switch windows"));

    m_gestureArray.append(buttomSwipe);
    m_gestureArray.append(topSwipe);
    m_gestureArray.append(rightSwipe);
    m_gestureArray.append(downSwipe);
    m_gestureArray.append(horizenSwipe);
    vlayout->addWidget(buttomSwipe);
    vlayout->addWidget(topSwipe);
    vlayout->addWidget(rightSwipe);
    vlayout->addWidget(downSwipe);
    vlayout->addWidget(horizenSwipe);

    connect(buttomSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::bottomEdgeSwipe);
    });
    connect(topSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::topEdgeSwipe);
    });
    connect(rightSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::rightEdgeSwipe);
    });
    connect(downSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::fourFingersSwipeDown);
    });
    connect(horizenSwipe, &gestureWidget::getFocus, this, [=]() {
        playGif(screenGestureType::fourFingersHorizontalSwipe);
    });
    connect(ui->moreGestureButton, &QPushButton::clicked, this, [=]() {
        QString pluName = "ukui-control-center/TouchScreen";
        qDebug() << pluName;
        QString service_name = "com.kylinUserGuide.hotel_" + QString::number(getuid());
        QDBusInterface interface(service_name,
                                 KYLIN_USER_GUIDE_PATH,
                                 KYLIN_USER_GUIDE_INTERFACE,
                                 QDBusConnection::sessionBus(),
                                 this);
        QDBusMessage msg = interface.call("showGuide", pluName);
    });

    foreach (auto gesture, m_gestureArray) {
        connect(gesture, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
        connect(this, &TouchScreen::iconThemeChangedSignal, gesture, &gestureWidget::themeChanged);
    }
//    connect(buttomSwipe, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
//    connect(topSwipe, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
//    connect(rightSwipe, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
//    connect(downSwipe, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
//    connect(horizenSwipe, &gestureWidget::loseFocus, this, &TouchScreen::stopGif);
}

void TouchScreen::loadGif()
{
//    ui->video_widget->setStyleSheet("border-image: none; background: green; border:none");
    QLabel *video_label = new QLabel(ui->video_widget);
    video_label->setFixedSize(400, 240);
//    video_label->setStyleSheet("border-image: none; background: yellow; border:none");
    QVBoxLayout *videoLayout = new QVBoxLayout(ui->video_widget);
    videoLayout->setContentsMargins(0, 0, 16, 0);
    videoLayout->addWidget(video_label);
    m_movie = new QMovie;
    m_movie->setFileName(":/gif/resources/下边缘上划显示多任务视图.gif");
//    m_movie->setScaledSize(QSize(384, 250));
    m_movie->setScaledSize(QSize(385, 231));
    m_movie->start();
    m_movie->stop();
    video_label->setMovie(m_movie);

//    QObject::connect(m_movie, &QMovie::frameChanged, [=](int frameNumber) {
//        // GIF 动画执行三次就结束
//        if (frameNumber == m_movie->frameCount() - 1)
//        {
//            m_cycleNum++;
//            if(m_cycleNum >= maxCycleNum) {
//                m_cycleNum = 0;
//                m_movie->stop();
//                // 停止播放后，跳转到第一页
//                m_movie->jumpToFrame(0);
//            }
//        }
//    });

}

void TouchScreen::playGif(screenGestureType type)
{
    switch (type) {
    case screenGestureType::bottomEdgeSwipe:
        m_movie->setFileName(":/gif/resources/下边缘上划显示多任务视图.gif");
        break;
    case screenGestureType::topEdgeSwipe:
        m_movie->setFileName(":/gif/resources/上边缘下划显示桌面.gif");
        break;
    case screenGestureType::rightEdgeSwipe:
        m_movie->setFileName(":/gif/resources/右边缘左划显示侧边栏.gif");
        break;
    case screenGestureType::fourFingersSwipeDown:
        m_movie->setFileName(":/gif/resources/四指向下划动显示搜索.gif");
        break;
    case screenGestureType::fourFingersHorizontalSwipe:
        m_movie->setFileName(":/gif/resources/四指水平滑动显示窗口切换.gif");
        break;
    default:
        break;
    }
    m_movie->stop();
    m_cycleNum = 0;
    m_movie->start();
}

void TouchScreen::stopGif()
{
    m_movie->stop();
//     停止播放后，跳转到第一页
    m_movie->jumpToFrame(0);
}

//    // 下面这种方式可以加载 mp4 文件，但是控制面板加载会报 QXcbConnection 的错误
//    // 用 demo 加载插件不会出现此问题，暂时没有思路
//void TouchScreen::loadVideo()
//{
//    ui->video_widget->setStyleSheet("border-image: none; background: green; border:none");
//    player = new QMediaPlayer;
//    medialist = new QMediaPlaylist;
//    medialist->addMedia(QUrl::fromLocalFile("/home/pangyi/touchgesture/touchgesture/单指边缘-多任务视图.mp4"));
//    medialist->addMedia(QUrl::fromLocalFile("/home/pangyi/touchgesture/touchgesture/单指向下-显示桌面.mp4"));
//    medialist->setPlaybackMode(QMediaPlaylist::CurrentItemInLoop);
//    player->setPlaylist(medialist);
//    connect(player, QOverload<QMediaPlayer::Error>::of(&QMediaPlayer::error),
//          [=](QMediaPlayer::Error error){
//        qDebug() << error;
//    });
//    connect(player, &QMediaPlayer::stateChanged, this, &TouchscreenSettings::stateChanged);
//    connect(player, &QMediaPlayer::mediaStatusChanged, this, &TouchscreenSettings::mediaStatusChanged);

//    QVBoxLayout *videoLayout = new QVBoxLayout(ui->video_widget);

//    videoWidget = new QVideoWidget;
//    videoWidget->installEventFilter(this);
//    videoWidget->setFixedSize(400, 400);
//    videoLayout->setContentsMargins(0, 0, 0, 0);
//    videoLayout->addWidget(videoWidget);
//    player->setVideoOutput(videoWidget);
//}

//void TouchScreen::startVideo1()
//{
//    medialist->setCurrentIndex(1);
//    videoWidget->show();
//    player->play();
//}

//void TouchScreen::mediaStatusChanged(QMediaPlayer::MediaStatus status)
//{
//    switch (status) {
//    case QMediaPlayer::UnknownMediaStatus:
//        qDebug() << "媒体未知状况！";
//        break;
//    case QMediaPlayer::NoMedia:
//        qDebug() << "没有媒体文件！";
//        break;
//    case QMediaPlayer::BufferingMedia:
//        qDebug() << "正在缓冲媒体文件！";
//        break;
//    case QMediaPlayer::BufferedMedia:
//        qDebug() << "媒体文件缓冲完成！" << videoWidget->contentsMargins() << videoWidget->contentsRect() << videoWidget->geometry() << videoWidget->size() << videoWidget->baseSize();
//        break;
//    case QMediaPlayer::LoadingMedia:
//        qDebug() << "正在加载媒体！";
//        break;
//    case QMediaPlayer::StalledMedia:
//        qDebug() << "播放停滞！";
//        break;
//    case QMediaPlayer::EndOfMedia:
//        qDebug() << "播放结束！";
//        break;
//    case QMediaPlayer::LoadedMedia:
//        qDebug() << "媒体加载完成！";
//        break;
//    case QMediaPlayer::InvalidMedia:
//        qDebug() << "不可用的媒体文件！";
//        break;
//    default: break;
//    }
//}

//void TouchScreen::stateChanged(QMediaPlayer::State state)
//{
//    switch (state) {
//    case QMediaPlayer::StoppedState:
//        qDebug() << "停止状态！";
//        break;
//    case QMediaPlayer::PlayingState:
//        qDebug() << "播放状态！";
//        break;
//    case QMediaPlayer::PausedState:
//        qDebug() << "暂停状态！";
//        break;
//    default: break;
//    }
//}
